==> huaweicloudsdkworkspace-3.1.155-py2.py3-none-any.whl: huaweicloudsdkworkspace/v2/model/show_quotas_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ShowQuotasResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'quotas': 'QuotaNoLimit',
        'site_quotas': 'list[SiteQuotaNoLimit]'
    }

    attribute_map = {
        'quotas': 'quotas',
        'site_quotas': 'site_quotas'
    }

    def __init__(self, quotas=None, site_quotas=None):
        r"""ShowQuotasResponse

        The model defined in huaweicloud sdk

        :param quotas: 
        :type quotas: :class:`huaweicloudsdkworkspace.v2.QuotaNoLimit`
        :param site_quotas: 站点配额信息，暂不包括中心站点
        :type site_quotas: list[:class:`huaweicloudsdkworkspace.v2.SiteQuotaNoLimit`]
        """
        
        super(ShowQuotasResponse, self).__init__()

        self._quotas = None
        self._site_quotas = None
        self.discriminator = None

        if quotas is not None:
            self.quotas = quotas
        if site_quotas is not None:
            self.site_quotas = site_quotas

    @property
    def quotas(self):
        r"""Gets the quotas of this ShowQuotasResponse.

        :return: The quotas of this ShowQuotasResponse.
        :rtype: :class:`huaweicloudsdkworkspace.v2.QuotaNoLimit`
        """
        return self._quotas

    @quotas.setter
    def quotas(self, quotas):
        r"""Sets the quotas of this ShowQuotasResponse.

        :param quotas: The quotas of this ShowQuotasResponse.
        :type quotas: :class:`huaweicloudsdkworkspace.v2.QuotaNoLimit`
        """
        self._quotas = quotas

    @property
    def site_quotas(self):
        r"""Gets the site_quotas of this ShowQuotasResponse.

        站点配额信息，暂不包括中心站点

        :return: The site_quotas of this ShowQuotasResponse.
        :rtype: list[:class:`huaweicloudsdkworkspace.v2.SiteQuotaNoLimit`]
        """
        return self._site_quotas

    @site_quotas.setter
    def site_quotas(self, site_quotas):
        r"""Sets the site_quotas of this ShowQuotasResponse.

        站点配额信息，暂不包括中心站点

        :param site_quotas: The site_quotas of this ShowQuotasResponse.
        :type site_quotas: list[:class:`huaweicloudsdkworkspace.v2.SiteQuotaNoLimit`]
        """
        self._site_quotas = site_quotas

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ShowQuotasResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkworkspace-3.1.158-py2.py3-none-any.whl: huaweicloudsdkworkspace/v2/model/show_quotas_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ShowQuotasResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'quotas': 'QuotaNoLimit',
        'site_quotas': 'list[SiteQuotaNoLimit]'
    }

    attribute_map = {
        'quotas': 'quotas',
        'site_quotas': 'site_quotas'
    }

    def __init__(self, quotas=None, site_quotas=None):
        r"""ShowQuotasResponse

        The model defined in huaweicloud sdk

        :param quotas: 
        :type quotas: :class:`huaweicloudsdkworkspace.v2.QuotaNoLimit`
        :param site_quotas: 站点配额信息，暂不包括中心站点。
        :type site_quotas: list[:class:`huaweicloudsdkworkspace.v2.SiteQuotaNoLimit`]
        """
        
        super(ShowQuotasResponse, self).__init__()

        self._quotas = None
        self._site_quotas = None
        self.discriminator = None

        if quotas is not None:
            self.quotas = quotas
        if site_quotas is not None:
            self.site_quotas = site_quotas

    @property
    def quotas(self):
        r"""Gets the quotas of this ShowQuotasResponse.

        :return: The quotas of this ShowQuotasResponse.
        :rtype: :class:`huaweicloudsdkworkspace.v2.QuotaNoLimit`
        """
        return self._quotas

    @quotas.setter
    def quotas(self, quotas):
        r"""Sets the quotas of this ShowQuotasResponse.

        :param quotas: The quotas of this ShowQuotasResponse.
        :type quotas: :class:`huaweicloudsdkworkspace.v2.QuotaNoLimit`
        """
        self._quotas = quotas

    @property
    def site_quotas(self):
        r"""Gets the site_quotas of this ShowQuotasResponse.

        站点配额信息，暂不包括中心站点。

        :return: The site_quotas of this ShowQuotasResponse.
        :rtype: list[:class:`huaweicloudsdkworkspace.v2.SiteQuotaNoLimit`]
        """
        return self._site_quotas

    @site_quotas.setter
    def site_quotas(self, site_quotas):
        r"""Sets the site_quotas of this ShowQuotasResponse.

        站点配额信息，暂不包括中心站点。

        :param site_quotas: The site_quotas of this ShowQuotasResponse.
        :type site_quotas: list[:class:`huaweicloudsdkworkspace.v2.SiteQuotaNoLimit`]
        """
        self._site_quotas = site_quotas

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ShowQuotasResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
